@@ -5,7 +5,7 @@
 
 from __future__ import absolute_import
 
-from .eval7 import evaluate, hand_type
+from .evaluate import evaluate, handtype
 from .cards import Card, Deck, ranks, suits
 from .equity import py_hand_vs_range_monte_carlo, py_hand_vs_range_exact, py_all_hands_vs_range
-from .hand_range import HandRange
+from .handrange import HandRange
